const objectHash = require('object-hash');

const verifySignature = require('../verify-signature');
const { forum } = require('../db');

const write = async ({
  sender, authors, content, citations, embeddedData, signature,
}) => {
  // Check author signature
  if (!verifySignature({
    sender, authors, content, signature, embeddedData,
  })) {
    const err = new Error();
    err.status = 403;
    err.message = 'Signature verification failed';
    throw err;
  }

  // Compute content hash
  const data = {
    sender, authors, content, signature, embeddedData, citations,
  };
  const hash = objectHash({
    sender, authors, content, signature, embeddedData,
  });

  // Store content
  await forum.put(hash, data);

  // Return hash
  return { hash, data };
};

module.exports = write;
